@@ -24,11 +24,28 @@ fn main() {
     let path = PathBuf::from("../../sdk/bpf/syscalls.txt");
     let file = match File::create(&path) {
         Ok(x) => x,
-        _ => exit(1),
+        // _ => exit(0),
+        _ => return,
+
     };
     let mut out = BufWriter::new(file);
     let sysc_re = Regex::new(r#"register_syscall_by_name\([[:space:]]*b"([^"]+)","#).unwrap();
     for caps in sysc_re.captures_iter(text) {
         writeln!(out, "{}", caps[1].to_string()).unwrap();
     }
+
+    // let exist = path.exists();
+    // if !exist {
+    //     let file = match File::create(&path) {
+    //         Ok(x) => x,
+    //         _ => exit(1),
+    //         // _ => return,
+    
+    //     };
+    //     let mut out = BufWriter::new(file);
+    //     let sysc_re = Regex::new(r#"register_syscall_by_name\([[:space:]]*b"([^"]+)","#).unwrap();
+    //     for caps in sysc_re.captures_iter(text) {
+    //         writeln!(out, "{}", caps[1].to_string()).unwrap();
+    //     }
+    // }
 }
